EncryptionKey class

A Google Cloud KMS encryption key.

Constructors

EncryptionKey({required String name, required String ring, String region = 'global'})
Constructor.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The key name.
final
region String
The key region.
final
ring String
The key ring.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited