User class
The request's authenticated user.
Constructors
Properties
- accountDisabled → bool
-
Whether the user account is disabled.
final
- email → String
-
The user email address.
final
- emailVerified → bool
-
Whether the user email address is verified.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
The subject.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited